@@ -7,7 +7,7 @@ from wechatpyyyy.client.api.base import BaseWeChatAPI
 
 
 class WeChatWxa(BaseWeChatAPI):
-    API_BASE_URL = 'http://api.weixin.qq.com/'
+    API_BASE_URL = 'https://api.weixin.qq.com/'
 
     def create_qrcode(self, path, width=430):
         """
